@@ -19,8 +19,6 @@ PromptDestinationCommand: TypeAlias = PushPrompts | DeletePrompts
 
 
 class PromptDestination(Protocol):
-    def get_all_prompts(self) -> Sequence[DestinationPrompt]:
-        ...
+    def get_all_prompts(self) -> Sequence[DestinationPrompt]: ...
 
-    def update(self, commands: Sequence[PromptDestinationCommand]) -> None:
-        ...
+    def update(self, commands: Sequence[PromptDestinationCommand]) -> None: ...
