@@ -12,8 +12,6 @@ def submit_pr(c: inv.Context):
 def create_branch_from_issue(c: inv.Context, selected_issue: GithubIssue):
     sanitised_title = sanitise_issue_title(selected_issue.title)
     branch_title = f"{selected_issue.number}-{sanitised_title}"
-    first_commit_str = (
-        f"$'{selected_issue.title}\n\nFixes #{selected_issue.number}'"
-    )
+    first_commit_str = f"$'{selected_issue.title}\n\nFixes #{selected_issue.number}'"
     c.run(f"gt create {branch_title} --all -m {first_commit_str}")
     c.run(f"git commit --allow-empty -m {first_commit_str}")
