@@ -15,23 +15,11 @@ def test_hash_cleaned_str_should_ignore_punctuation():
         f"{s}{punctuation}" for s in strings_should_hash_to_identical
     ]
 
-    assert (
-        len(
-            {
-                hash_str_to_int(clean_str(s))
-                for s in strings_should_hash_to_identical
-            }
-        )
-        == 1
-    )
+    assert len({hash_str_to_int(clean_str(s)) for s in strings_should_hash_to_identical}) == 1
 
 
-@pytest.mark.parametrize(
-    ("input_str", "hash_identical_str"), [("<p>Test</p>", "Test"), ("å", "å")]
-)
-def test_hash_cleaned_str_should_remove_html_tags(
-    input_str: str, hash_identical_str: str
-):
+@pytest.mark.parametrize(("input_str", "hash_identical_str"), [("<p>Test</p>", "Test"), ("å", "å")])
+def test_hash_cleaned_str_should_remove_html_tags(input_str: str, hash_identical_str: str):
     assert hash_cleaned_str(input_str) == hash_cleaned_str(hash_identical_str)
 
 
